@@ -1,10 +1,11 @@
 use strict;
 use warnings;
-use v5.10;
 use Path::Class qw( file dir );
 
 exit unless $ENV{ARCHIVE_LIBARCHIVE_FFI_BUILD_IMPORT};
 
+sub say { print @_, "\n" }
+
 require Archive::Libarchive::XS;
 
 do { # constants.pm
